@@ -39,7 +39,7 @@ class VarMiddleTest(TestCase):
     def test_bad_class2(self):
         pattern = VarDeclarationDistance(lines_th=5)
         lines = pattern.value(os.path.dirname(os.path.realpath(__file__)) + '/3.java')
-        self.assertEqual(lines, [783, 969])
+        self.assertEqual(sorted(lines), [214, 783, 969])
 
     def test_case_with_multiline_function_arguments(self):
         pattern = VarDeclarationDistance(lines_th=2)
